"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.GhGqlClient = void 0;
const graphql_tag_1 = __importDefault(require("graphql-tag"));
const apollo_client_1 = require("apollo-client");
const apollo_cache_inmemory_1 = require("apollo-cache-inmemory");
const apollo_link_http_1 = require("apollo-link-http");
const undici_1 = require("undici");
const contextQuery = (0, graphql_tag_1.default) `
  query UpdatePrCommentContext($branchName: String!, $owner: String!, $repository: String!) {
    repository(owner: $owner, name: $repository) {
      nameWithOwner
      ref(qualifiedName: $branchName) {
        associatedPullRequests(last: 5, states: OPEN) {
          totalCount
          nodes {
            id
            number
            comments(first: 50) {
              totalCount
              nodes {
                id
                body
              }
            }
          }
        }
      }
    }
  }
`;
const createCommentMutation = (0, graphql_tag_1.default) `
  mutation AddCommentMutation($id: ID!, $body: String!) {
    addComment(input: { subjectId: $id, body: $body, clientMutationId: "" }) {
      commentEdge {
        node {
          id
        }
      }
    }
  }
`;
const updateCommentMutation = (0, graphql_tag_1.default) `
  mutation UpdateCommentMutation($id: ID!, $body: String!) {
    updateIssueComment(input: { id: $id, body: $body }) {
      issueComment {
        id
      }
    }
  }
`;
class GhGqlClient {
    constructor(token, urlStr) {
        const url = new URL(urlStr);
        this._client = new apollo_client_1.ApolloClient({
            link: (0, apollo_link_http_1.createHttpLink)({
                uri: url.pathname !== "/" ? urlStr : `${urlStr}/api/graphql`,
                headers: {
                    Authorization: `bearer ${token}`,
                },
                fetch: undici_1.fetch,
            }),
            cache: new apollo_cache_inmemory_1.InMemoryCache(),
        });
    }
    postCommentToPr({ owner, repository, branchName, body, markerComment = "reg-comment", }) {
        return __awaiter(this, void 0, void 0, function* () {
            const { data, errors } = yield this._client.query({
                query: contextQuery,
                variables: {
                    owner,
                    repository,
                    branchName,
                },
            });
            if (!data) {
                throw errors || new Error();
            }
            if (!data || !data.repository) {
                throw new Error(`No matched repository: "${owner}/${repository}"`);
            }
            if (!data.repository.ref ||
                !data.repository.ref.associatedPullRequests ||
                !data.repository.ref.associatedPullRequests.totalCount) {
                // Nothing to do
                return [];
            }
            const pullRequests = data.repository.ref.associatedPullRequests.nodes;
            yield Promise.all(pullRequests.map((pullRequest) => __awaiter(this, void 0, void 0, function* () {
                if (pullRequest.comments && pullRequest.comments.nodes) {
                    const commentToBeUpdated = pullRequest.comments.nodes.find(c => c.body && c.body.startsWith(`<!-- ${markerComment} -->`));
                    if (commentToBeUpdated) {
                        const { errors } = yield this._client.mutate({
                            mutation: updateCommentMutation,
                            variables: {
                                id: commentToBeUpdated.id,
                                body: `<!-- ${markerComment} -->\n${body}`,
                            },
                        });
                        if (errors)
                            throw errors;
                        return;
                    }
                }
                const { errors } = yield this._client.mutate({
                    mutation: createCommentMutation,
                    variables: {
                        id: pullRequest.id,
                        body: `<!-- ${markerComment} -->\n${body}`,
                    },
                });
                if (errors)
                    throw errors;
                return;
            })));
            return pullRequests.map(p => p.number);
        });
    }
}
exports.GhGqlClient = GhGqlClient;
//# sourceMappingURL=gh-gql-client.js.map